<h1 align="center">kilroy-server-py-utils</h1>

<div align="center">

utilities for kilroy servers in Python 🔧

[![Lint](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/lint.yaml/badge.svg)](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/lint.yaml)
[![Tests](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/test-multiplatform.yaml/badge.svg)](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/test-multiplatform.yaml)
[![Docs](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/docs.yaml/badge.svg)](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/docs.yaml)

</div>

---

## Overview

This package contains code useful to implement **kilroy** servers in Python.
Mostly it's just a bunch of utilities and base classes.

## Installing

Using `pip`:

```sh
pip install kilroy-server-py-utils
```
